@@ -1,8 +1,8 @@
 from dbconf import dbs
 import os
 
-from connectors.postgres import postgres
-from connectors.googleAnalytics import googleAnalytics
+from postgres import postgres
+from googleAnalytics import googleAnalytics
 
 connectors = {
   'postgres' : postgres,
